@@ -1,10 +1,19 @@
-require 'pathname'
 require 'rubygems'
 
-gem 'rspec', '~>1.1.11'
-require 'spec'
+# Use local dm-core if running from a typical dev checkout.
+lib = File.join('..', '..', 'dm-core', 'lib')
+$LOAD_PATH.unshift(lib) if File.directory?(lib)
+require 'dm-core'
 
-require Pathname(__FILE__).dirname.parent.expand_path + 'lib/dm-timestamps'
+# Use local dm-validations if running from a typical dev checkout.
+lib = File.join('..', 'dm-validations', 'lib')
+$LOAD_PATH.unshift(lib) if File.directory?(lib)
+require 'dm-validations'
+
+# Support running specs with 'rake spec' and 'spec'
+$LOAD_PATH.unshift('lib') unless $LOAD_PATH.include?('lib')
+
+require 'dm-timestamps'
 
 def load_driver(name, default_uri)
   return false if ENV['ADAPTER'] != name.to_s
